==> lima-swing-0.5-sources.jar: org/chorem/lima/ui/lettering/LetteringViewHandler.java <==
/*
 * #%L
 * Lima Swing
 * 
 * $Id: LetteringViewHandler.java 3141 2011-05-23 14:15:17Z vsalaun $
 * $HeadURL: http://svn.chorem.org/svn/lima/tags/lima-0.5/lima-swing/src/main/java/org/chorem/lima/ui/lettering/LetteringViewHandler.java $
 * %%
 * Copyright (C) 2008 - 2010 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

package org.chorem.lima.ui.lettering;

import static org.nuiton.i18n.I18n._;

import java.util.Date;

import javax.swing.JComboBox;
import javax.swing.JTextField;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.chorem.lima.business.FinancialTransactionServiceMonitorable;
import org.chorem.lima.business.LimaException;
import org.chorem.lima.entity.Letter;
import org.chorem.lima.service.LimaServiceFactory;
import org.chorem.lima.ui.combobox.FinancialPeriodComboBoxModel;
import org.chorem.lima.ui.combobox.FiscalPeriodComboBoxModel;
import org.chorem.lima.util.DialogHelper;


/**
 * Handler associated with financial transaction view.
 * 
 * @author chatellier
 * @version $Revision: 3141 $
 * 
 * Last update : $Date: 2011-05-23 16:15:17 +0200 (Mon, 23 May 2011) $
 * By : $Author: vsalaun $
 */
public class LetteringViewHandler {

    /** log. */
    private static final Log log =
        LogFactory.getLog(LetteringViewHandler.class);

    protected LetteringView view;
    
    protected LetteringTable table;
    
    protected LetteringTableModel tableModel;
    
    protected FiscalPeriodComboBoxModel fiscalPeriodComboBoxModel;
    
    protected FinancialPeriodComboBoxModel financialPeriodComboBoxModel;
    
    /** Transaction service. */
    protected final FinancialTransactionServiceMonitorable financialTransactionService;
    
    protected Object clipBoard;

    protected LetteringViewHandler(LetteringView view) {
        this.view = view;
        
        /* Services */
        financialTransactionService =
            LimaServiceFactory.getInstance().getService(
                    FinancialTransactionServiceMonitorable.class);
    }
    
    public void setBeginDate(Date date){
        tableModel = view.getTableModel();
        tableModel.setSelectedBeginDate(date);
    }
    
    public void setEndDate(Date date){
        tableModel = view.getTableModel();
        tableModel.setSelectedEndDate(date);
    }
    
   public void addLetter(){
       Letter letter = null;
       Boolean valid = true;
       
       table = view.getTable();
       tableModel = view.getTableModel();
       
       AddLetterForm addLetterForm = new AddLetterForm();
       JTextField newLetterTextField = addLetterForm.getNewLetterTextField();

       try {
           letter = financialTransactionService.getNewLetter();
           newLetterTextField.setText(letter.getCode());
       } catch (LimaException eee) {
           log.error("Can't get new letter", eee);
       }
       
       addLetterForm.setLocationRelativeTo(view);
       addLetterForm.setVisible(true);
       
       //false = cancel Action
       if (addLetterForm.validOk){
           Object object = addLetterForm.getRadioButtons().getSelectedValue();
           if (!(Boolean) object){
               JComboBox comboBox = addLetterForm.getLetterListComboBox();
               Object selectedObject = comboBox.getSelectedItem();
               if (selectedObject instanceof Letter){
                   letter = (Letter) selectedObject;
               }
               else {
                       DialogHelper.showMessageDialog(_("lima.entries.lettering.noletterselected"));
                       valid = false;
               }
           }
           if (valid){
               //addLetters
               int[] rows = table.getSelectedRows();
               for (int i : rows) {
                   tableModel.setLetter(i, letter);
                }
               tableModel.refresh();
           }
       } 
   }
   
   public void removeLetter(){

       table = view.getTable();
       tableModel = view.getTableModel();
       
       //removeLetters
       int[] rows = table.getSelectedRows();
       for (int i : rows) {
           tableModel.removeLetter(i);
        }
       tableModel.refresh();
   }
   
    public void refresh(){
        tableModel = view.getTableModel();
        tableModel.refresh();
    }
}

==> lima-swing-0.5.1-sources.jar: org/chorem/lima/ui/lettering/LetteringViewHandler.java <==
/*
 * #%L
 * Lima Swing
 * 
 * $Id: LetteringViewHandler.java 3278 2011-08-16 14:09:44Z tchemit $
 * $HeadURL: http://svn.chorem.org/svn/lima/tags/lima-0.5.1/lima-swing/src/main/java/org/chorem/lima/ui/lettering/LetteringViewHandler.java $
 * %%
 * Copyright (C) 2008 - 2010 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

package org.chorem.lima.ui.lettering;

import static org.nuiton.i18n.I18n._;

import java.util.Date;

import javax.swing.JComboBox;
import javax.swing.JTextField;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.chorem.lima.business.FinancialTransactionServiceMonitorable;
import org.chorem.lima.business.LimaException;
import org.chorem.lima.entity.Letter;
import org.chorem.lima.service.LimaServiceFactory;
import org.chorem.lima.ui.combobox.FinancialPeriodComboBoxModel;
import org.chorem.lima.ui.combobox.FiscalPeriodComboBoxModel;
import org.chorem.lima.util.DialogHelper;


/**
 * Handler associated with financial transaction view.
 * 
 * @author chatellier
 * @version $Revision: 3278 $
 * 
 * Last update : $Date: 2011-08-16 16:09:44 +0200 (Tue, 16 Aug 2011) $
 * By : $Author: tchemit $
 */
public class LetteringViewHandler {

    /** log. */
    private static final Log log =
        LogFactory.getLog(LetteringViewHandler.class);

    protected LetteringView view;
    
    protected LetteringTable table;
    
    protected LetteringTableModel tableModel;
    
    protected FiscalPeriodComboBoxModel fiscalPeriodComboBoxModel;
    
    protected FinancialPeriodComboBoxModel financialPeriodComboBoxModel;
    
    /** Transaction service. */
    protected final FinancialTransactionServiceMonitorable financialTransactionService;
    
    protected Object clipBoard;

    protected LetteringViewHandler(LetteringView view) {
        this.view = view;
        
        /* Services */
        financialTransactionService =
            LimaServiceFactory.getInstance().getService(
                    FinancialTransactionServiceMonitorable.class);
    }
    
    public void setBeginDate(Date date){
        tableModel = view.getTableModel();
        tableModel.setSelectedBeginDate(date);
    }
    
    public void setEndDate(Date date){
        tableModel = view.getTableModel();
        tableModel.setSelectedEndDate(date);
    }
    
   public void addLetter(){
       Letter letter = null;
       Boolean valid = true;
       
       table = view.getTable();
       tableModel = view.getTableModel();
       
       AddLetterForm addLetterForm = new AddLetterForm();
       JTextField newLetterTextField = addLetterForm.getNewLetterTextField();

       try {
           letter = financialTransactionService.getNewLetter();
           newLetterTextField.setText(letter.getCode());
       } catch (LimaException eee) {
           log.error("Can't get new letter", eee);
       }
       
       addLetterForm.setLocationRelativeTo(view);
       addLetterForm.setVisible(true);
       
       //false = cancel Action
       if (addLetterForm.validOk){
           Object object = addLetterForm.getRadioButtons().getSelectedValue();
           if (!(Boolean) object){
               JComboBox comboBox = addLetterForm.getLetterListComboBox();
               Object selectedObject = comboBox.getSelectedItem();
               if (selectedObject instanceof Letter){
                   letter = (Letter) selectedObject;
               }
               else {
                       DialogHelper.showMessageDialog(_("lima.entries.lettering.noletterselected"));
                       valid = false;
               }
           }
           if (valid){
               //addLetters
               int[] rows = table.getSelectedRows();
               for (int i : rows) {
                   tableModel.setLetter(i, letter);
                }
               tableModel.refresh();
           }
       } 
   }
   
   public void removeLetter(){

       table = view.getTable();
       tableModel = view.getTableModel();
       
       //removeLetters
       int[] rows = table.getSelectedRows();
       for (int i : rows) {
           tableModel.removeLetter(i);
        }
       tableModel.refresh();
   }
   
    public void refresh(){
        tableModel = view.getTableModel();
        tableModel.refresh();
    }
}
